@@ -46,9 +46,12 @@ class CmeelConfig:
         conf: Dict[str, Any],
         install: Union[Path, str],
         configure_args: Dict[str, Any],
+        configure_env: {str: str},
+        run_tests: bool,
     ) -> [str]:
         """Get CMake initial arguments."""
         project = conf["name"]
+        build_testing = [] if run_tests else ["-DBUILD_TESTING=OFF"]
         ret = (
             [
                 "-DBoost_NO_WARN_NEW_VERSIONS=ON",
@@ -58,11 +61,14 @@ class CmeelConfig:
                 f"-DPYTHON_SITELIB={SITELIB}",
                 f"-DPython3_EXECUTABLE={sys.executable}",
             ]
+            + build_testing
             + configure_args
             + self.conf.get("configure-args", [])
         )
         if project in self.conf:
             ret += self.conf[project].get("configure-args", [])
+        if "CMEEL_CMAKE_ARGS" in configure_env and configure_env["CMEEL_CMAKE_ARGS"]:
+            ret += configure_env["CMEEL_CMAKE_ARGS"].split()
         return ret
 
     def get_configure_env(self) -> {str: str}:
